diff mpegvideo.c @ 726:a91203b34e71 libavcodec

moved dct init out from mpv_common_init to dct_common_init (for less-uglier way for dv)
author al3x
date Fri, 04 Oct 2002 20:59:29 +0000
parents 71f669e9f633
children b24ea84b23e2
line wrap: on
line diff
--- a/mpegvideo.c	Fri Oct 04 07:49:00 2002 +0000
+++ b/mpegvideo.c	Fri Oct 04 20:59:29 2002 +0000
@@ -179,11 +179,10 @@
     add_pixels_clamped(block, dest, line_size);
 }
 
-/* init common structure for both encoder and decoder */
-int MPV_common_init(MpegEncContext *s)
+/* init common dct for both encoder and decoder */
+int DCT_common_init(MpegEncContext *s)
 {
-    int c_size, i;
-    UINT8 *pict;
+    int i;
 
     s->dct_unquantize_h263 = dct_unquantize_h263_c;
     s->dct_unquantize_mpeg1 = dct_unquantize_mpeg1_c;
@@ -219,7 +218,6 @@
 #ifdef HAVE_MMI
     MPV_common_init_mmi(s);
 #endif
-    
 
     /* load & permutate scantables
        note: only wmv uses differnt ones 
@@ -229,6 +227,17 @@
     ff_init_scantable(s, &s->intra_h_scantable, ff_alternate_horizontal_scan);
     ff_init_scantable(s, &s->intra_v_scantable, ff_alternate_vertical_scan);
 
+    return 0;
+}
+
+/* init common structure for both encoder and decoder */
+int MPV_common_init(MpegEncContext *s)
+{
+    int c_size, i;
+    UINT8 *pict;
+
+    DCT_common_init(s);
+
     s->mb_width = (s->width + 15) / 16;
     s->mb_height = (s->height + 15) / 16;